@@ -1,5 +1,5 @@
 /* GNU Gama -- adjustment of geodetic networks
-   Copyright (C) 1999, 2012  Ales Cepek <cepek@gnu.org>
+   Copyright (C) 1999, 2012, 2018  Ales Cepek <cepek@gnu.org>
 
    This file is part of the GNU Gama C++ library.
 
@@ -20,14 +20,18 @@
 #include <gnu_gama/statan.h>
 #include <gnu_gama/radian.h>
 #include <cfloat>
+#include <cmath>
+#include <iostream>
+
+// #include <cmath>
 
 using namespace std;
 
 namespace GNU_gama {
 
-float Student(float palfa, int N)
+double Student(double palfa, int N)
 {
-   float alfa = palfa;
+   double alfa = palfa;
    if(alfa > 0.5) alfa=1.0-alfa;
    alfa *= 2;
 
@@ -35,26 +39,26 @@ float Student(float palfa, int N)
 
    if (N <= 1)
    {
-      float a = M_PI/2*alfa;
-      float stu_ = cos(a)/sin(a);
+      double a = M_PI/2*alfa;
+      double stu_ = cos(a)/sin(a);
       if (palfa > 0.5) stu_ = -stu_;
       return stu_;
    }
 
    if (N <= 2)
    {
-      float stu_ = sqrt(2.0/(alfa*(2.0-alfa))-2.0);
+      double stu_ = sqrt(2.0/(alfa*(2.0-alfa))-2.0);
       if (palfa > 0.5) stu_ = -stu_;
       return stu_;
     }
 
-   float r = N;
-   float a = 1.0/(r-0.5);
-   float b = 48.0/(a*a);
-   float c = ((20700.0*a/b-98.0)*a-16.0)*a+96.36;
-   float d = ((94.5/(b+c)-3.0)/b+1.0)*sqrt(M_PI/2*a)*r;
-   float x = d*alfa, xx = 2.0/r;
-   float y = pow(x,xx);
+   double r = N;
+   double a = 1.0/(r-0.5);
+   double b = 48.0/(a*a);
+   double c = ((20700.0*a/b-98.0)*a-16.0)*a+96.36;
+   double d = ((94.5/(b+c)-3.0)/b+1.0)*sqrt(M_PI/2*a)*r;
+   double x = d*alfa, xx = 2.0/r;
+   double y = pow(x,xx);
 
    if (y > a+0.05)
    {
@@ -68,14 +72,14 @@ float Student(float palfa, int N)
          y = 0.5*y*y+y;
       else
          y = exp(y)-1.0;
-      float stu_ = sqrt(r*y);
+      double stu_ = sqrt(r*y);
       if (palfa > 0.5) stu_ = -stu_;
       return stu_;
    }
 
    y = ((1.0/(((r+6.0)/(r*y)-0.089*d-0.822)*(r+2.0)*3.0)+0.5/(r+4.0))
         *y-1.0)*(r+1.0)/(r+2.0)+1.0/y;
-   float stu_ = sqrt(r*y);
+   double stu_ = sqrt(r*y);
    if (palfa > 0.5) stu_ = -stu_;
    return stu_;
 
@@ -199,38 +203,63 @@ void NormalDistribution(double x, double& D, double& f)
    if (typv) D = 0; else D = 1;
 }
 
-float KSprob(float lambda)
+double KSprob(double x)
 {
-   const float eps = 1.0e-8;
-   const float C = -2*lambda*lambda;
-   float term;
-   float j = 1;
-   float sum = 0;
+   const double eps = 1e-20;
+   if (x < eps) return 0.0;
+   if (x > 1.0/eps) return 1.0;
 
-   do {
-      term = exp(C*j*j);  j++;  sum += term;
-      term = exp(C*j*j);  j++;  sum -= term;
-   } while (term > eps*sum && j < 100);
+   double sum {};
+   double term;
 
-   return j<100 ? 2*sum : 1;
+   if (x < 1.18)
+     {
+       const double pi2  = M_PI*M_PI;
+       const double xx8  = 8*x*x;
+
+       sum = 0;
+       for (double j=1; j<100; j++) {
+         double nom = (-4.0*j*j + 4.0*j - 1)*pi2;  // -(2*j-1)*(2*j-1)*pi2;
+         term = exp(nom/xx8);
+         sum += term;
+         if (term < eps) break;
+       }
+       sum *= sqrt(2*M_PI)/x;
+     }
+   else
+     {
+       const double x2 = -2*x*x;
+       double k = 1.0;
+       double s = -2.0;
+
+       sum = 1;
+       do {
+         term = exp(x2*k*k);
+         sum += s*term;
+         s = -s;
+         k++;
+       } while (term > eps && k <= 100);
+     }
+
+   return sum;
 }
 
-float Chi_square(float p, int n)
+double Chi_square(double p, int n)
 {
    if (n < 2)
    {
-      float a = Normal(0.5*p);
+      double a = Normal(0.5*p);
       return a*a;
    }
    else if (n == 2)
       return -2.0*log(p);
 
-   float f=n;
-   float f1=1.0/f;
-   float t=Normal(p);
-   float f2=sqrt(f1)*t;
+   double f=n;
+   double f1=1.0/f;
+   double t=Normal(p);
+   double f2=sqrt(f1)*t;
 
-   float z;
+   double z;
    if(n < (2+int(4*fabs(t))))
       z=(((((((0.1565326e-2*f2 + 0.1060438e-2)*f2 - 0.6950356e-2)*f2 -
       0.1323293e-1)*f2 + 0.2277679e-1)*f2 - 0.8986007e-2)*f2 - 0.1513904e-1)
@@ -249,4 +278,32 @@ float Chi_square(float p, int n)
    return f*z*z*z;
 }
 
+void KStest(double Data[], int n, double (*Func)(double),
+            double& ks, double& prob){
+   using namespace std;
+
+   std::sort(Data, Data+n);
+
+   const double  float_n = n;
+   double Fa = 0, Fb, Fi, dl, du, dt;
+   double d = 0;
+   for (int i=0; i<n;)
+   {
+      Fi = Func(Data[i]);
+      Fb = ++i/float_n;
+      dl = fabs(Fa - Fi);
+      du = fabs(Fb - Fi);
+      dt = dl > du ? dl : du;
+      Fa = Fb;
+      if (dt > d) d = dt;
+   }
+
+   double sn = sqrt(float_n);
+   //dt = (sn + 0.12 + 0.11/sn)*d;
+   dt = sn*d;
+   ks = d;
+   prob = 1 - KSprob(dt);
+}
+
+
 }   // namespace GNU_gama::local
